# Generated by roxygen2: do not edit by hand

S3method(plot,htdv_fit)
S3method(print,htdv_fit)
S3method(summary,htdv_fit)
export(htdv_bf)
export(htdv_boot)
export(htdv_composite)
export(htdv_conformal)
export(htdv_diagnostics)
export(htdv_envelope)
export(htdv_equivalence_constants)
export(htdv_fit)
export(htdv_fixedb)
export(htdv_lrv)
export(htdv_mpc)
export(htdv_ppc)
export(htdv_rope)
export(htdv_simstudy)
export(htdv_simstudy_summary)
export(htdv_simstudy_warnings)
export(htdv_stack)
export(htdv_summary)
export(htdv_tac)
export(htdv_waic_lfo)
export(htdv_whittle)
export(htdv_wsc)
